from zope.catalog.interfaces import ICatalog
from zope.component import queryUtility
from zope.component.hooks import setSite
from waeup.ikoba.app import Company
from waeup.ikoba.payments.payment import Payment
from waeup.ikoba.payments.testing import FakePayer, FakePayable
from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
from waeup.ikoba.payments.catalog import search


class FunctionalPaymentCatalogTests(FunctionalTestCase):

    layer = FunctionalLayer

    def create_app(self):
        self.root = self.getRootFolder()
        self.app = Company()
        self.root['app'] = self.app
        setSite(self.app)
        return self.app

    def test_catalog_available(self):
        # the payments catalog will be available in ICompany objects
        self.create_app()
        catalog = queryUtility(ICatalog, name='payments_catalog')
        assert catalog is not None

    def test_catalog_catalogs_ipayments(self):
        # the catalog will register IPayment objects stored
        app = self.create_app()
        payment = Payment(payer=FakePayer(), payable=FakePayable())
        app['p1'] = payment
        result = search(query=payment.payment_id, searchtype='payment_id')
        result = [x for x in result]
        self.assertEqual(len(result), 1)

    def test_search_for_payer_id(self):
        # the catalog will search in payer_id field
        app = self.create_app()
        payer = FakePayer()
        payer.payer_id = u'ThePayerID'
        payment = Payment(payer=payer, payable=FakePayable())
        app['p1'] = payment
        result = search(query='ThePayerID', searchtype='payer_id')
        result = [x for x in result]
        self.assertEqual(len(result), 1)
